summaryrefslogtreecommitdiff
path: root/gemini.go
diff options
context:
space:
mode:
authortjpcc <tjp@ctrl-c.club>2023-09-23 13:01:11 -0600
committertjpcc <tjp@ctrl-c.club>2023-09-23 13:03:19 -0600
commitd59ed1060d354ce911da1e7fb19f651feeafa2c1 (patch)
treee751e6e113c665c86fd9411fe53caf91c4b0d582 /gemini.go
parent6cfa6622f31953bd75bfae4c9b10915e3dd6bd78 (diff)
use :repository as the repo name key
Diffstat (limited to 'gemini.go')
-rw-r--r--gemini.go34
1 files changed, 17 insertions, 17 deletions
diff --git a/gemini.go b/gemini.go
index 63477d5..cf7db73 100644
--- a/gemini.go
+++ b/gemini.go
@@ -16,37 +16,37 @@ import (
const (
repokey = "syw_repo"
- reponamekey = "syw_reponame"
+ reponamekey = "repository"
)
// GeminiRouter builds a router that will handle requests into a directory of git repositories.
//
// The routes it defines are:
-// / gemtext listing of the repositories in the directory
-// /:syw_reponame[/] gemtext overview of the repository
-// /:syw_reponame/branches gemtext list of branches/heads
-// /:syw_reponame/tags gemtext listing of tags
-// /:syw_reponame/refs/:ref/ gemtext overview of a ref
-// /:syw_reponame/refs/:ref/tree/*path gemtext listing of directories, raw files
-// /:syw_reponame/diffstat/:fromref/:toref text/plain diffstat between two refs
-// /:syw_reponame/diff/:fromref/:toref text/x-diff between two refs
+// / gemtext listing of the repositories in the directory
+// /:repository/ gemtext overview of the repository
+// /:repository/branches gemtext list of branches/heads
+// /:repository/tags gemtext listing of tags
+// /:repository/refs/:ref/ gemtext overview of a ref
+// /:repository/refs/:ref/tree/*path gemtext listing of directories, raw files
+// /:repository/diffstat/:fromref/:toref text/plain diffstat between two refs
+// /:repository/diff/:fromref/:toref text/x-diff between two refs
//
// The overrides argument can provide templates to define the behavior of nearly all of the above
// routes. All of them have default implementations so the argument can even be nil, but otherwise
// the template names used are:
// repo_root.gmi gemtext at /
// repo_home.gmi gemtext at /:syw_reponame/
// branch_list.gmi gemtext at /:syw_reponame/branches
// tag_list.gmi gemtext at /:syw_reponame/tags
// ref.gmi gemtext at /:syw_reponame/refs/:ref/
// tree.gmi gemtext for directories requested under /:syw_reponame/refs/:ref/tree/*path
// (file paths return the raw files without any template involved)
// diffstat.gmi the plaintext diffstat at /:syw_reponame/diffstat/:fromref/:toref
// diff.gmi the text/x-diff at /:syw_reponame/diff/:fromref/:toref
//
// Most of the templates above are rendered with an object with 3 fields:
// Ctx: the context.Context from the request
-// Repo: a *syw.Repository object corresponding to <repodir>/:syw_reponame
+// Repo: a *syw.Repository object corresponding to <repodir>/:repository
// Params: a map[string]string of the route parameters
//
// The only exception is repo_root.gmi, which is rendered with a slice of the repo names instead.
@@ -16,37 +16,37 @@ import (
// the template names used are:
// repo_root.gmi gemtext at /
-// repo_home.gmi gemtext at /:syw_reponame/
-// branch_list.gmi gemtext at /:syw_reponame/branches
-// tag_list.gmi gemtext at /:syw_reponame/tags
-// ref.gmi gemtext at /:syw_reponame/refs/:ref/
-// tree.gmi gemtext for directories requested under /:syw_reponame/refs/:ref/tree/*path
+// repo_home.gmi gemtext at /:repository/
+// branch_list.gmi gemtext at /:repository/branches
+// tag_list.gmi gemtext at /:repository/tags
+// ref.gmi gemtext at /:repository/refs/:ref/
+// tree.gmi gemtext for directories requested under /:repository/refs/:ref/tree/*path
// (file paths return the raw files without any template involved)
@@ -16,37 +16,37 @@ import (
// (file paths return the raw files without any template involved)
-// diffstat.gmi the plaintext diffstat at /:syw_reponame/diffstat/:fromref/:toref
-// diff.gmi the text/x-diff at /:syw_reponame/diff/:fromref/:toref
+// diffstat.gmi the plaintext diffstat at /:repository/diffstat/:fromref/:toref
+// diff.gmi the text/x-diff at /:repository/diff/:fromref/:toref
//
// Most of the templates above are rendered with an object with 3 fields: